CHAT_MESSAGES = [
	{"role": "system", "content": "You are a helpful assistant."},
	{"role": "user", "content": 'Who won the 2001 world series?'},
	{"role": "assistant", "content": 'The arizona diamondbacks won the 2001 world series.'},
	{"role": "user", "content": 'Who were the pitchers?'},
]

FUNCTION_MESSAGES = [
	{"role": "system", "content": "You are a helpful assistant."},
	{"role": "user", "content": 'What is the length of supercalifragilisticexpialidocious?'},
]
